Split out isrg from ssr and reorient build graph to make interpreter build 2x faster (#2969)

* split out isrg and core-types to speed up interpreter build
This commit is contained in:
Jonathan Kelley authored and GitHub committed 2024-09-16 16:49:06 -07:00
1 parent f0d814fede
commit 143ad749ea
28 files changed
+197 -231

No files matched your search

+1 -1
View File
@@ -62,7 +62,7 @@ pub mod prelude {
#[cfg(feature = "server")]
#[cfg_attr(docsrs, doc(cfg(feature = "server")))]
pub use dioxus_ssr::incremental::{IncrementalRenderer, IncrementalRendererConfig};
pub use dioxus_isrg::{IncrementalRenderer, IncrementalRendererConfig};
pub use dioxus_server_macro::*;
pub use server_fn::{self, ServerFn as _, ServerFnError};